==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/PropIter__242.h <==
// class soot.jimple.spark.solver.PropIter$2

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor
// @dep_class 3fe80ce86e916e8f soot_jimple_spark_solver_PropIter__242

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetVisitor

#include "soot/jimple/spark/sets/P2SetVisitor.h"

#ifndef _JC_soot_jimple_spark_solver_PropIter__242_H_
#define _JC_soot_jimple_spark_solver_PropIter__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;
struct _jc_soot_jimple_spark_solver_PropIter$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$sub_refs	_jc_soot_jimple_spark_solver_PropIter__242$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs	_jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$refs	_jc_soot_jimple_spark_solver_PropIter__242$refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$nonrefs	_jc_soot_jimple_spark_solver_PropIter__242$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$object	_jc_soot_jimple_spark_solver_PropIter__242$object;

typedef const struct _jc_soot_jimple_spark_solver_PropIter__242$vmethods	_jc_soot_jimple_spark_solver_PropIter__242$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropIter__242$vtable	_jc_soot_jimple_spark_solver_PropIter__242$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropIter__242$vtype	_jc_soot_jimple_spark_solver_PropIter__242$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropIter__242$method$_init$0136b7867927a8f1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter__242$object *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_object *, struct _jc_object_array *);

// Virtual methods
extern void _jc_soot_jimple_spark_solver_PropIter__242$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter__242$object *, struct _jc_soot_jimple_spark_pag_Node$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropIter__242$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropIter__242$vmethods {
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter__242$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropIter__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
	_jc_soot_jimple_spark_solver_PropIter__242$vmethods	soot_jimple_spark_solver_PropIter__242;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropIter__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropIter__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter__242$sub_refs {
	struct _jc_object	*val__24f;
	_jc_object_array	*val__24loadTargets;
	struct _jc_soot_jimple_spark_solver_PropIter$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter__242$refs {
    _jc_soot_jimple_spark_solver_PropIter__242$sub_refs	soot_jimple_spark_solver_PropIter__242;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs	soot_jimple_spark_solver_PropIter__242;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropIter__242$object {
	_jc_soot_jimple_spark_solver_PropIter__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropIter__242$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropIter__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropIter__242$vtype _jc_soot_jimple_spark_solver_PropIter__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropIter__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropIter__242$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropIter__242_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/PropIter__242.h <==
// class soot.jimple.spark.solver.PropIter$2

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor
// @dep_class 3fe80ce86e916e8f soot_jimple_spark_solver_PropIter__242

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetVisitor

#include "soot/jimple/spark/sets/P2SetVisitor.h"

#ifndef _JC_soot_jimple_spark_solver_PropIter__242_H_
#define _JC_soot_jimple_spark_solver_PropIter__242_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;
struct _jc_soot_jimple_spark_solver_PropIter$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$sub_refs	_jc_soot_jimple_spark_solver_PropIter__242$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs	_jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$refs	_jc_soot_jimple_spark_solver_PropIter__242$refs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$nonrefs	_jc_soot_jimple_spark_solver_PropIter__242$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropIter__242$object	_jc_soot_jimple_spark_solver_PropIter__242$object;

typedef const struct _jc_soot_jimple_spark_solver_PropIter__242$vmethods	_jc_soot_jimple_spark_solver_PropIter__242$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropIter__242$vtable	_jc_soot_jimple_spark_solver_PropIter__242$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropIter__242$vtype	_jc_soot_jimple_spark_solver_PropIter__242$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropIter__242$method$_init$0136b7867927a8f1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter__242$object *, struct _jc_soot_jimple_spark_solver_PropIter$object *, struct _jc_object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_solver_PropIter__242$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter__242$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropIter__242$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropIter__242$vmethods {
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropIter__242$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropIter__242$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
	_jc_soot_jimple_spark_solver_PropIter__242$vmethods	soot_jimple_spark_solver_PropIter__242;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropIter__242$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropIter__242$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter__242$sub_refs {
	struct _jc_object	*val__24f;
	_jc_object_array	*val__24loadTargets;
	struct _jc_soot_jimple_spark_solver_PropIter$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter__242$refs {
    _jc_soot_jimple_spark_solver_PropIter__242$sub_refs	soot_jimple_spark_solver_PropIter__242;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropIter__242$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_soot_jimple_spark_solver_PropIter__242$sub_nonrefs	soot_jimple_spark_solver_PropIter__242;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropIter__242$object {
	_jc_soot_jimple_spark_solver_PropIter__242$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropIter__242$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropIter__242$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropIter__242$vtype _jc_soot_jimple_spark_solver_PropIter__242$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropIter__242, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropIter__242$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropIter__242_H_ */
